@@ -134,7 +134,7 @@ class Ui_MainWindow(object):
         self.tab_button(self, self.tab_edit,
                         (230, 0, 40, 40), "Crop the Image", "Crop")
         self.button.clicked.connect(self.crop)
-        self.button.setIcon(QtGui.QIcon(self.location + "/images/crop.svg"))
+        self.button.setIcon(QtGui.QIcon(self.location + "/images/Crop.svg"))
         self.button.setIconSize(QtCore.QSize(40, 40))
 
         # Color Buttons
@@ -304,7 +304,7 @@ class Ui_MainWindow(object):
                                     x)
                     self.button.setMaximumSize(40, 40)
                     self.button.clicked.connect(lambda checked, name=x: self.process_custom(name))
-                    self.button.setIcon(QtGui.QIcon(self.location + "/images/custom.svg"))
+                    self.button.setIcon(QtGui.QIcon(self.location + "/images/Custom.svg"))
                     self.button.setIconSize(QtCore.QSize(40, 40))
                     self.horizontalLayout2.addWidget(self.button)
                     self.horizontalLayout2.addWidget(self.button, 0, QtCore.Qt.AlignLeft)
