@@ -1,7 +1,7 @@
 from PyQt5 import QtWidgets
 import sys
 import os
-import gui
+from simpledit import gui
 
 def RunApp():
     app = QtWidgets.QApplication(sys.argv)
